==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebSelectHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownHeaderDescriptionMetadata } from "./WebDropdownHeaderDescriptionMetadata";
import { WebSelectHeaderDescription } from "./WebSelectHeaderDescription";
/**
 * @hidden
 */
export let WebSelectHeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSelectHeaderDescriptionMetadata extends Base {
        static b(a) {
            if (WebSelectHeaderDescriptionMetadata.a == null) {
                WebSelectHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSelectHeaderDescriptionMetadata.c(WebSelectHeaderDescriptionMetadata.a);
            }
            if (a.k(WebSelectHeaderDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebSelectHeaderDescriptionMetadata.a);
        }
        static c(a) {
            WebDropdownHeaderDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:SelectHeader");
            a.item("__tagNameWC", "String:igc-select-header");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebSelectHeaderDescriptionMetadata.b(a);
            a.ad("WebSelectHeader", () => new WebSelectHeaderDescription());
            a.ac("WebSelectHeader", WebSelectHeaderDescriptionMetadata.a);
        }
    }
    WebSelectHeaderDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSelectHeaderDescriptionMetadata, 'WebSelectHeaderDescriptionMetadata');
    WebSelectHeaderDescriptionMetadata.a = null;
    return WebSelectHeaderDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebSelectHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSelectHeaderDescription } from "./WebSelectHeaderDescription";
/**
 * @hidden
 */
export let WebSelectHeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSelectHeaderDescriptionMetadata extends Base {
        static b(a) {
            if (WebSelectHeaderDescriptionMetadata.a == null) {
                WebSelectHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSelectHeaderDescriptionMetadata.c(WebSelectHeaderDescriptionMetadata.a);
            }
            if (a.k(WebSelectHeaderDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebSelectHeaderDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SelectHeader");
            a.item("__tagNameWC", "String:igc-select-header");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebSelectHeaderDescriptionMetadata.b(a);
            a.ae("WebSelectHeader", () => new WebSelectHeaderDescription());
            a.ad("WebSelectHeader", WebSelectHeaderDescriptionMetadata.a);
        }
    }
    WebSelectHeaderDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSelectHeaderDescriptionMetadata, 'WebSelectHeaderDescriptionMetadata');
    WebSelectHeaderDescriptionMetadata.a = null;
    return WebSelectHeaderDescriptionMetadata;
})();
